/*-----------------------------------------------------------------------
esurban_table1.do

Stata do file to replicate table 1 of the article
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies
-----------------------------------------------------------------------*/

* Initialise
clear all
set more off
set matsize 2000
quietly capture log close
log using ../../output/esurban_table1, text replace

* Read panel
use ../../output/mcvl_panel, clear
* Generate extra variables
gen ln_earnings = ln(earnings)
gen experience2 = experience^2
gen tenure2 = tenure^2
* Generate variables in table absent from panel
gen ln_size = .
gen city_dummies = .
gen fixed_effects = .
* Save temp panel
tempfile mcvlpanel
save "`mcvlpanel'", replace

* Define controls
local controls_a "experience experience2 tenure tenure2 skill_1 skill_2 skill_3 skill_4"
local controls_b "edu_tertiary edu_secondary"
local controls_c "contract_fixedterm contract_parttime date_2 - date_72 sector2d_16 - sector2d_95"

* Column (1), 1st stage pooled OLS
reg ln_earnings ua_id_1 - ua_id_82 `controls_a' `controls_b' `controls_c', cluster(person_id)
est2vec esurban_table1, e(r2) vars(ln_size city_dummies fixed_effects  `controls_a' `controls_b') name(a)

* Combine 1st stage coefficients for city indicators with log city size
matrix COEFF = e(b)'
gen num_obs = 1
collapse (sum) num_obs, by (ua_id)
svmat double COEFF, names(col)
replace y1 = 0 if ua_id == 83
drop if missing(ua_id)
rename y1 premium_pooled
merge 1:1 ua_id using ../../otherdata/ua_size, keepusing(size_pop10k)
drop if _merge == 2
drop _merge num_obs
gen ln_size = ln(size_pop10k)
drop size_pop10k
save ../../output/esurban_table1_premia, replace

* Column (2), 2nd stage OLS
reg premium_pooled ln_size, robust
est2vec esurban_table1, addto(esurban_table1) name(b)

* Column (3), 1st stage fixed-effects
use "`mcvlpanel'", clear
xtset person_id date
xtreg ln_earnings ua_id_1 - ua_id_82 `controls_a' `controls_c', fe cluster(person_id)
xtset, clear
est2vec esurban_table1, addto(esurban_table1) name(c)

* Save coefficients for later use when generating figures
est2vec esurban_table1tmp, e(r2) name(c)
matsave esurban_table1tmp_b, replace saving path(../../output/)
preserve
use ../../output/esurban_table1tmp_b, clear
erase ../../output/esurban_table1tmp_b.dta
rename _rowname coeff_var
rename c coeff_fe
gen coeff_no = _n
order coeff_no coeff_var coeff_fe
keep coeff_no coeff_var coeff_fe
save ../../output/esurban_table1_coeff, replace
restore

* Combine 1st stage coefficients for city indicators with log city size
matrix COEFF = e(b)'
gen num_obs = 1
collapse (sum) num_obs, by (ua_id)
svmat double COEFF, names(col)
replace y1 = 0 if ua_id == 83
drop if missing(ua_id)
rename y1 premium_fe
merge 1:1 ua_id using ../../output/esurban_table1_premia
drop _merge num_obs

* Column (4), 2nd stage fixed-effects
reg premium_fe ln_size, robust
est2vec esurban_table1, addto(esurban_table1) name(d)

* Save premia for later use when generating figures
keep ua_id premium_pooled premium_fe
order ua_id premium_pooled premium_fe
label var ua_id "Urban area"
label var premium_pooled "City indicator coefficients (table 1, column 1)"
label var premium_fe "City indicator coefficients (table 1, column 3)"
save ../../output/esurban_table1_premia, replace

* Label variables for table
use "`mcvlpanel'", clear
label var ln_size "Log city size"
label var city_dummies "City indicators"
label var fixed_effects "Worker fixed-effects"
label var experience "Experience"
label var experience2 "Experience$^2$"
label var tenure "Firm tenure"
label var tenure2 "Firm tenure$^2$"
label var edu_secondary "Secondary education"
label var edu_tertiary "University education"
label var skill_1 "Very-high-skilled occupation"
label var skill_2 "High-skilled occupation"
label var skill_3 "Medium-high-skilled occupation"
label var skill_4 "Medium-low-skilled occupation"
label var edu_tertiary "University education"
label var edu_secondary "Secondary education"
* Produce LaTeX table
est2texdp esurban_table1, label preserve replace path(../../output/) levels(90 95 99) mark(stars) digits(4) leadzero flexible(0) fancy
erase ../../output/esurban_table1_tbl.dta

log close

