/*-----------------------------------------------------------------------
esurban_table2.do

Stata do file to replicate table 2 of the article
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies
-----------------------------------------------------------------------*/

* Initialise
clear all
set more off
set matsize 2000
quietly capture log close
log using ../../output/esurban_table2, text replace

* Read panel
use ../../output/mcvl_panel, clear
* Generate extra variables
gen ln_earnings = ln(earnings)
gen experience2 = experience^2
gen tenure2 = tenure^2
gen uexp_1_2_exp = uexp_1_2 * experience
gen uexp_3_5_exp = uexp_3_5 * experience
gen uexp_1_2_now5 = uexp_1_2 * ua_1_5
gen uexp_1_2_exp_now5 = uexp_1_2_exp * ua_1_5
gen uexp_3_5_now5 = uexp_3_5 * ua_1_5
gen uexp_3_5_exp_now5 = uexp_3_5_exp * ua_1_5
gen uexp_smaller_now5 = uexp_smaller * ua_1_5
gen uexp_smaller_exp_now5 = uexp_smaller * experience * ua_1_5
* Generate variables in table absent from panel
gen ln_size = .
gen city_dummies = .
gen fixed_effects = .
* Save temp panel
tempfile mcvlpanel
save "`mcvlpanel'", replace

* Define mean local experience
summarize uexp_current, meanonly
local mean_exp `r(mean)'

* Define controls
local controls_a "uexp_1_2 uexp_1_2_exp uexp_3_5 uexp_3_5_exp experience experience2 uexp_1_2_now5 uexp_1_2_exp_now5 uexp_3_5_now5 uexp_3_5_exp_now5 uexp_smaller_now5 uexp_smaller_exp_now5 tenure tenure2 skill_1 skill_2 skill_3 skill_4"
local controls_b "contract_fixedterm contract_parttime date_2 - date_72 sector2d_16 - sector2d_95"

* Column (1), 1st stage fixed-effects
xtset person_id date
xtreg ln_earnings ua_id_1 - ua_id_82 `controls_a' `controls_b', fe cluster(person_id)
xtset, clear

* Save coefficients for later use when generating figures
est2vec esurban_table2, e(r2) name(a)
matsave esurban_table2_b, replace saving path(../../output/)
preserve
use ../../output/esurban_table2_b, clear
erase ../../output/esurban_table2_b.dta
rename _rowname coeff_var
rename a coeff
gen coeff_no = _n
order coeff_no coeff_var coeff
save ../../output/esurban_table2_coeff, replace
restore
est2vec esurban_table2, replace e(r2) vars(ln_size city_dummies fixed_effects `controls_a') name(a)

* Combine 1st stage coefficients for city indicators with medium term premium and log city size
matrix COEFF = e(b)'
gen num_obs = 1
collapse (sum) num_obs, by (ua_id)
svmat double COEFF, names(col)
replace y1 = 0 if ua_id == 83
drop if missing(ua_id)
rename y1 premium_initial
gen uexp_1_2 = _b[uexp_1_2] * `mean_exp' if ua_id == 1 | ua_id == 2
gen uexp_1_2_exp = _b[uexp_1_2_exp] * `mean_exp'^2 if ua_id == 1 | ua_id == 2
gen uexp_3_5  = _b[uexp_3_5] * `mean_exp' if ua_id == 3 | ua_id == 4 | ua_id == 8
gen uexp_3_5_exp = _b[uexp_3_5_exp] * `mean_exp'^2 if ua_id == 3 | ua_id == 4 | ua_id == 8
gen uexp_1_2_now5 = _b[uexp_1_2_now5] * `mean_exp' if ua_id == 1 | ua_id == 2
gen uexp_1_2_exp_now5 = _b[uexp_1_2_exp_now5] * `mean_exp'^2 if ua_id == 1 | ua_id == 2
gen uexp_3_5_now5 = _b[uexp_3_5_now5] * `mean_exp' if ua_id == 3 | ua_id == 4 | ua_id == 8
gen uexp_3_5_exp_now5 = _b[uexp_3_5_exp_now5] * `mean_exp'^2 if ua_id == 3 | ua_id == 4 | ua_id == 8
egen premium_exp = rowtotal(uexp_1_2 - uexp_3_5_exp_now5)
gen premium_medterm = premium_initial + premium_exp
drop premium_exp uexp_*
merge 1:1 ua_id using ../../otherdata/ua_size, keepusing(size_pop10k)
drop if _merge == 2
drop _merge num_obs
gen ln_size = ln(size_pop10k)
drop size_pop10k

* Column (2), 2nd stage initial premium
reg premium_initial ln_size, robust
est2vec esurban_table2, addto(esurban_table2) name(b)

* Column (3), 2nd stage medium premium
reg premium_medterm ln_size, robust
est2vec esurban_table2, addto(esurban_table2) name(c)

* Save premia for later use when generating figures
keep ua_id premium_initial premium_medterm
order ua_id premium_initial premium_medterm
label var ua_id "Urban area"
label var premium_initial "City indicator coefficients (table 2, column 1)"
label var premium_medterm "City indicator coefficients (table 2, column 1) + `mean_exp' years local exp."
save ../../output/esurban_table2_premia, replace

* Label variables for table
use "`mcvlpanel'", clear
label var ln_size "Log city size"
label var city_dummies "City indicators"
label var fixed_effects "Worker fixed-effects"
label var uexp_1_2 "Experience 1$^\text{st}$-2$^\text{nd}$ biggest cities"
label var uexp_1_2_exp "Experience 1$^\text{st}$-2$^\text{nd}$ biggest cities $\times$ experience"
label var uexp_3_5 "Experience 3$^\text{rd}$-5$^\text{th}$ biggest cities"
label var uexp_3_5_exp "Experience 3$^\text{rd}$-5$^\text{th}$ biggest cities $\times$ experience"
label var experience "Experience"
label var experience2 "Experience$^2$"
label var uexp_1_2_now5 "Experience 1$^\text{st}$-2$^\text{nd}$ biggest $\times$ now in 5 biggest"
label var uexp_1_2_exp_now5 "Experience 1$^\text{st}$-2$^\text{nd}$ biggest $\times$ experience $\times$ now in 5 biggest"
label var uexp_3_5_now5 "Experience 3$^\text{rd}$-5$^\text{th}$ biggest $\times$ now in 5 biggest"
label var uexp_3_5_exp_now5 "Experience 3$^\text{rd}$-5$^\text{th}$ biggest $\times$ experience $\times$ now in 5 biggest"
label var uexp_smaller_now5 "Experience outside 5 biggest $\times$ now in 5 biggest"
label var uexp_smaller_exp_now5 "Experience outside 5 biggest $\times$ experience $\times$ now in 5 biggest"
label var tenure "Firm tenure"
label var tenure2 "Firm tenure$^2$"
label var skill_1 "Very-high-skilled occupation"
label var skill_2 "High-skilled occupation"
label var skill_3 "Medium-high-skilled occupation"
label var skill_4 "Medium-low-skilled occupation"
* Produce LaTeX table
est2texdp esurban_table2, label preserve replace path(../../output/) levels(90 95 99) mark(stars) digits(4) leadzero flexible(0) fancy
erase ../../output/esurban_table2_tbl.dta

log close

