/*-----------------------------------------------------------------------
esurban_table4_boot.do

Stata do file called by esurban_table4.do
to replicate table 4 and initiate table 6 of the article
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies
-----------------------------------------------------------------------*/

* Initialise
set more off
set matsize 2000

* Set number of bootstrap iterations
local bstotal = 100

* Allocate bootstrap iterations to job
local pt = ($pll_instance)
local bsperjob = floor( `bstotal' / $PLL_CLUSTERS )
if ( `bstotal' / $PLL_CLUSTERS ) - floor( `bstotal' / $PLL_CLUSTERS ) == 0.5 {
  if ($pll_instance <= $PLL_CLUSTERS / 2) {
    local bsprevious = ($pll_instance - 1) * `bsperjob'
    local bslast = $pll_instance * `bsperjob'  
  }
  else {
    local bsprevious = (($PLL_CLUSTERS / 2) * `bsperjob') + (($pll_instance - 1 - ($PLL_CLUSTERS / 2)) * (`bsperjob' + 1))
    local bslast = (($PLL_CLUSTERS / 2) * `bsperjob') + (($pll_instance - ($PLL_CLUSTERS / 2)) * (`bsperjob' + 1))
  }
}
else {
  local bsprevious = ($pll_instance - 1) * `bsperjob'
  if ($pll_instance == $PLL_CLUSTERS) {
    local bslast = `bstotal'
  }
  else {
    local bslast = $pll_instance * `bsperjob'
  }
}

* Define tempfiles
tempfile tmp_panel_boot
tempfile it_fe
tempfile it_xb

* Define controls
local controls "uexp_1_2 uexp_1_2_exp uexp_3_5 uexp_3_5_exp experience experience2 uexp_1_2_now5 uexp_1_2_exp_now5 uexp_3_5_now5 uexp_3_5_exp_now5 uexp_smaller_now5 uexp_smaller_exp_now5 tenure tenure2 skill_1 skill_2 skill_3 skill_4 contract_fixedterm contract_parttime date_2 - date_72 sector2d_16 - sector2d_95"

* Bootstrap for standard errors of column (1) of table 4 and table 6
matrix COEFF = J(220,1,10^6)
local bsno = `bsprevious'
while `bsno' < `bslast' {
  local bsno = `bsno' + 1
  * Create bootstrap sample
  use ../../output/tmp_panel, clear
  bsample if cat == 0, cluster (person_id)
  save "`tmp_panel_boot'", replace
  foreach num of numlist 1/2 {
    use ../../output/tmp_panel, clear
    bsample if cat == `num', cluster (person_id)
    append using "`tmp_panel_boot'"
    save "`tmp_panel_boot'", replace
  }
  * Create new identifier
  sort person_id date
  egen order_id = seq(), by (person_id date)
  replace order_id = order_id - 1
  gen long nident = person_id * 100 + order_id
  order person_id order_id nident cat
  sort person_id order_id date
  compress
  save "`tmp_panel_boot'", replace
  * Obtain initial fe from baseline estimation of table 4
  merge m:1 person_id using ../../output/esurban_table4_fe
  keep if _merge == 3
  drop _merge
  collapse (mean) fe, by (nident)
  save "`it_fe'", replace
  * Initialise for loop
  local itno = 0
  local ssd_coef = 100
  local rmse = 100
  local d_rmse = 100
  matrix drop COEFF
  matrix COEFF = J(220,1,10^6)
  * Iterate until convergence
  while `ssd_coef' >= 1 | `d_rmse' >= 1 {
    quiet{
      local itno = `itno' + 1
      use "`tmp_panel_boot'", clear
      * Recover previous set of fixed-effects
      merge m:1 nident using "`it_fe'"
      drop _merge
      * Update interactions of estimated fixed-effects and experience variables
      replace fe_uexp_1_2 = fe * uexp_1_2
      replace fe_uexp_1_2_exp = fe * uexp_1_2_exp
      replace fe_uexp_3_5 = fe * uexp_3_5
      replace fe_uexp_3_5_exp = fe * uexp_3_5_exp
      replace fe_exp = fe * experience
      replace fe_exp2 = fe * experience2
      replace ln_earnings_fe = ln_earnings - fe
      * Estimate the value of such interactions and all other coefficients using pooled OLS
      reg ln_earnings_fe ua_id_1 - ua_id_82 fe_uexp_1_2 - fe_exp2 `controls', vce(cluster nident)
      local rmse_1 = e(rmse)
      matrix COEFFN = e(b)'
      * Predict dependent variable excluding interactions between estimated fixed-effects and experience variables
      preserve
      foreach var of varlist fe_uexp_1_2 - fe_exp2 {
        replace `var' = 0
      }
      predict xb
      keep nident year month xb
      save `it_xb', replace
      restore
      merge 1:1 nident year month using `it_xb', keepusing(xb)
      drop _merge
      * Calculate new set of fixed-effects
      gen double fe_numerator = ln_earnings - xb
      gen double fe_denominator = 1 + _b[fe_uexp_1_2]*uexp_1_2 + _b[fe_uexp_1_2_exp]*uexp_1_2_exp + _b[fe_uexp_3_5]*uexp_3_5 + _b[fe_uexp_3_5_exp]*uexp_3_5_exp + _b[fe_exp]*experience + _b[fe_exp2]*experience2 
      replace fe_denominator = 0.001 if fe_denominator == 0
      gen double fe_new = fe_numerator / fe_denominator
      collapse (mean) fe=fe_new, by (nident)
      save "`it_fe'", replace
      * Check for convergence in estimated coefficients between previous and current iteration
      clear
      set obs 1
      svmat double COEFF
      svmat double COEFFN
      gen double sd_coef = ((COEFFN1 - COEFF1)^2)*10^5
      egen ssdc = sum(sd_coef)
      matrix drop COEFF
      matrix rename COEFFN COEFF
      local ssd_coef "ssdc"
      local d_rmse = (`rmse' - `rmse_1')*10^7
      local rmse = `rmse_1'
    }
    display "Iteration `bsno'/`itno'"
    display "`c(current_date)', `c(current_time)'"
    display "SSD Coef.:" `ssd_coef'
    display "D RMSE: " `d_rmse'
    display ""
  }
  * Save last estimated fixed-effects (after convergence) for table 6 row 1
  use "`tmp_panel_boot'", clear
  merge m:1 nident using "`it_fe'"
  drop _merge
  preserve
  collapse (mean) fe`bsno'=fe, by (person_id order_id nident cat)
  merge 1:1 nident using ../../output/esurban_table6_fe_row1_part`pt'
  drop _merge
  save ../../output/esurban_table6_fe_row1_part`pt', replace
  restore
  * Re-estimate column (1) regression and save coefficients
  replace fe_uexp_1_2 = fe * uexp_1_2
  replace fe_uexp_1_2_exp = fe * uexp_1_2_exp
  replace fe_uexp_3_5 = fe * uexp_3_5
  replace fe_uexp_3_5_exp = fe * uexp_3_5_exp
  replace fe_exp = fe * experience
  replace fe_exp2 = fe * experience2
  replace ln_earnings_fe = ln_earnings - fe
  reg ln_earnings_fe ua_id_1 - ua_id_82 fe_uexp_1_2 - fe_exp2 `controls', vce(cluster nident)
  matrix drop COEFF
  matrix COEFF = e(b)'
  clear
  set obs 1
  svmat double COEFF
  keep COEFF1
  rename COEFF1 boot`bsno'
  gen coeff_no = _n
  merge 1:1 coeff_no using ../../output/esurban_table4_coeff_part`pt'
  drop _merge
  save ../../output/esurban_table4_coeff_part`pt', replace
  * Estimate fixed-effects for table 6 row 2
  use "`tmp_panel_boot'", clear
  xtset nident date
  preserve
  xtreg ln_earnings ua_id_1 - ua_id_82 `controls', fe cluster(nident)
  predict xb
  gen double resid = ln_earnings - xb
  collapse (mean) fe`bsno'=resid, by (person_id order_id nident cat)
  merge 1:1 nident using ../../output/esurban_table6_fe_row2_part`pt'
  drop _merge
  save ../../output/esurban_table6_fe_row2_part`pt', replace
  restore
  * Estimate fixed-effects for table 6 row 3
  xtreg ln_earnings ua_id_1 - ua_id_82 age age2 date_2 - date_72 sector2d_16 - sector2d_95, fe cluster(nident)
  xtset, clear
  predict xb
  gen double resid = ln_earnings - xb
  collapse (mean) fe`bsno'=resid, by (person_id order_id nident cat)
  merge 1:1 nident using ../../output/esurban_table6_fe_row3_part`pt'
  drop _merge
  save ../../output/esurban_table6_fe_row3_part`pt', replace
  * Save log earnings for table 6
  use "`tmp_panel_boot'", clear
  keep if date == 41
  rename ln_earnings w`bsno'
  keep person_id order_id nident cat w`bsno'
  merge 1:1 nident using ../../output/esurban_table6_w_part`pt'
  drop _merge
  save ../../output/esurban_table6_w_part`pt', replace
}
