/*-----------------------------------------------------------------------
make_mcvl.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies
-----------------------------------------------------------------------*/

clear
clear matrix
set more off
set matsize 3000

cd ./panel

** Read MCVL and tax data source files
* Create temporary folders for MCVL data sets
local cwd `"`c(pwd)'"'
quietly capture cd ../../tmp
if (_rc) mkdir ../../tmp
cd `cwd'
forvalues x = 2004(1)2013 {
  quietly capture cd ../../tmp/mcvl_cdf_`x'
  if (_rc) mkdir ../../tmp/mcvl_cdf_`x'
  cd `cwd'
}
* Read MCVL and tax data sets
forvalues x = 2004(1)2013 {
  do "mcvl_reading_`x'"
}
do "mcvl_reading_tax_data"

** MCVL 2013: Restrict sample to individuals born between 1962-1995 and obtain monthly panel information for 1980-2013
do "mcvl_cohort_setup"
forval num = 1962/1995 {
  use "../../tmp/mcvl_cdf_2013/individuals", clear
  drop if birth_date < `num'00 | birth_date > `num'12
  save "../../tmp/raw_cohort", replace
  do "mcvl_cohort_panel"
  gen mcvl_wave = 2013
  order person_id year month mcvl_wave
  compress
  label var mcvl_wave "MCVL wave used to extract individual SS information"
  save "../../tmp/cohort_`num'", replace
}

** MCVL 2005-2012: Sequentially, use information for individuals in these data sets who are not in MCVL 2013

* Individuals in MCVL 2012 that are absent in MCVL 2013
use "../../tmp/mcvl_cdf_2013/individuals", clear
drop if birth_date < 196200 | birth_date > 199512
keep person_id
merge 1:1 person_id using "../../tmp/mcvl_cdf_2012/individuals"
rename _merge merge_1213
drop if (birth_date < 196200 | birth_date > 199412) & merge_1213 == 2
keep person_id merge_*
save "../../tmp/merge_1213", replace
keep if merge_1213 == 2
drop merge_1213
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2012_panel"
gen mcvl_wave = 2012
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2012", replace

* Individuals in MCVL 2011 that are absent in MCVL 2012-2013
use "../../tmp/merge_1213", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2011/individuals"
rename _merge merge_1113
drop if (birth_date < 196200 | birth_date > 199312) & merge_1113 == 2
keep person_id merge_*
save "../../tmp/merge_1113", replace
keep if merge_1113 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2011_panel"
gen mcvl_wave = 2011
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2011", replace

* Individuals in MCVL 2010 that are absent in 2011-2013
use "../../tmp/merge_1113", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2010/individuals"
rename _merge merge_1013
drop if (birth_date < 196200 | birth_date > 199212) & merge_1013 == 2
keep person_id merge_*
save "../../tmp/merge_1013", replace
keep if merge_1013 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2010_panel"
gen mcvl_wave = 2010
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2010", replace

* Individuals in MCVL 2009 that are absent in 2010-2013
use "../../tmp/merge_1013", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2009/individuals"
rename _merge merge_0913
drop if (birth_date < 196200 | birth_date > 199112) & merge_0913 == 2
keep person_id merge_*
save "../../tmp/merge_0913", replace
keep if merge_0913 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2009_panel"
gen mcvl_wave = 2009
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2009", replace

* Individuals in MCVL 2008 that are absent in 2009-2013
use "../../tmp/merge_0913", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2008/individuals"
rename _merge merge_0813
drop if (birth_date < 196200 | birth_date > 199012) & merge_0813 == 2
keep person_id merge_*
save "../../tmp/merge_0813", replace
keep if merge_0813 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2008_panel"
gen mcvl_wave = 2008
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2008", replace

* Individuals in MCVL 2007 that are absent in 2008-2013
use "../../tmp/merge_0813", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2007/individuals"
rename _merge merge_0713
drop if (birth_date < 196200 | birth_date > 198912) & merge_0713 == 2
keep person_id merge_*
save "../../tmp/merge_0713", replace
keep if merge_0713 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2007_panel"
gen mcvl_wave = 2007
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2007", replace

* Individuals in MCVL 2006 that are absent in 2007-2013
use "../../tmp/merge_0713", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2006/individuals"
rename _merge merge_0613
drop if (birth_date < 196200 | birth_date > 198812) & merge_0613 == 2
keep person_id merge_*
save "../../tmp/merge_0613", replace
keep if merge_0613 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2006_panel"
gen mcvl_wave = 2006
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2006", replace

* Individuals in MCVL 2005 that are absent in 2006-2013
use "../../tmp/merge_0613", clear
merge 1:1 person_id using "../../tmp/mcvl_cdf_2005/individuals"
rename _merge merge_0513
drop if (birth_date < 196200 | birth_date > 198712) & merge_0513 == 2
keep person_id merge_*
save "../../tmp/merge_0513", replace
keep if merge_0513 == 2
drop merge_*
save "../../tmp/raw_cohort", replace
do "mcvl_cohort_2005_panel"
gen mcvl_wave = 2005
order person_id year month mcvl_wave
compress
label var mcvl_wave "MCVL wave used to extract individual SS information"
save "../../tmp/additional_2005", replace

foreach name in 05 06 07 08 09 10 11 12 {
  erase "../../tmp/merge_`name'13.dta"
}
foreach num of numlist 1/4 {
  erase "../../tmp/mcvl_affiliates_`num'.dta"
}
foreach num of numlist 1/13 {
  erase "../../tmp/mcvl_earnings_`num'.dta"
}

** Add tax earnings data

* Create time-varying sector of economic activity CNAE93
do "mcvl_firm_cnae93"

* Merges all annual tax data sets
do "mcvl_merge_tax"

* Merges MCVL and tax data sets
do "mcvl_merge_cohorts_tax"

** Prepare final sample for estimations
do "mcvl_panel"

* Label variables
do "mcvl_panel_labels"

* Save final panel
save "../../output/mcvl_panel", replace

cd ../

