/*-----------------------------------------------------------------------
mcvl_cohort_2011_panel.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Creates panel for individuals in MCVL 2011 & not in MCVLs 2012-2013
-----------------------------------------------------------------------*/

** Adjusts MCVL 2011 data sets for merging process
foreach num of numlist 1/3 {
  use "../../tmp/mcvl_cdf_2011/affiliates_`num'", clear
  * Generate unique observations by individual, entry date, exit date and firm id
  * Very few cases, non-uniqueness is mainly related to non-uniqueness in cause of dismissal
  egen count = seq(), by (person_id entry_date exit_date firm_id_sec)
  egen max = max(count), by (person_id entry_date exit_date firm_id_sec)
  drop if count != 1 & max > 1
  drop count max
  save "../../tmp/mcvl_affiliates_`num'", replace
}

foreach num of numlist 1/13 {
  use "../../tmp/mcvl_cdf_2011/contribution_`num'", clear
  * Rename MCVL earnings of 'base contributions'
  rename (earnings_jan earnings_feb earnings_mar earnings_apr earnings_may earnings_jun earnings_jul earnings_aug earnings_sep earnings_oct earnings_nov earnings_dec) /*
  */ (earnings_1 earnings_2 earnings_3 earnings_4 earnings_5 earnings_6 earnings_7 earnings_8 earnings_9 earnings_10 earnings_11 earnings_12)
  * Sort variables
  drop if year < 1980
  sort person_id firm_id_sec year
  save "../../tmp/mcvl_earnings_`num'", replace
}

** Merge individual-level data with spell data
* Spells can describe employment or unemployment events
* Each spell consists of a combination of entry date, exit date and firm identifier
use "../../tmp/raw_cohort", clear
keep person_id
merge 1:m person_id using "../../tmp/mcvl_affiliates_1", update replace
drop if _merge == 2
drop _merge
merge m:m person_id using "../../tmp/mcvl_affiliates_2", update replace
drop if _merge == 2
drop _merge
merge m:m person_id using "../../tmp/mcvl_affiliates_3", update replace
drop if _merge == 2
drop _merge

* Keep only those individuals that have at least one spell by 2011
* Drop individuals with missing firm identifiers throughout their lives
sort person_id entry_date exit_date
gen uno = 1 if firm_id_sec == ""
egen no_spell = min(uno), by (person_id)
drop if no_spell == 1
order person_id entry_date exit_date firm_id_sec
drop uno no_spell

** Goal: identify main spells in individual lives and create life histories of continuous spells
* Continuous entries and exits within the same firm are widespread in MCVL
* A subset of these turnovers involve firm changes and transitions into and out of unemployment

* Generate an entry date format for Stata
gen str12 entdate = string(entry_date,"%12.0g")
gen yr = substr(entdate,1,4)
gen mt = substr(entdate,5,2)
gen dy = substr(entdate,7,2)
destring yr, gen(yr1)
destring mt, gen(mt1)
destring dy, gen(dy1)
replace dy1 = 1 if yr1 < 1966
replace mt1 = 1 if yr1 < 1966
replace yr1 = 1966 if yr1 < 1966
replace mt1 = 1 if mt1 == 0
replace dy1 = 1 if dy1 == 0
replace dy1 = 28 if dy1 > 28 & mt1 == 2 & yr1 != 1972 & yr1 != 1976 & yr1 != 1980 & yr1 != 1984 & yr1 != 1988 & yr1 != 1992 & yr1 != 1996 & yr1 != 2000 & yr1 != 2004 & yr1 != 2008 & yr1 != 2012
gen entry = mdy(mt1,dy1,yr1)
drop entdate yr mt dy yr1 mt1 dy1
* Generate an exit date format for Stata
gen str12 exdate = string(exit_date,"%12.0g")
gen yr = substr(exdate,1,4)
gen mt = substr(exdate,5,2)
gen dy = substr(exdate,7,2)
destring yr, gen(yr1)
destring mt, gen(mt1)
destring dy, gen(dy1)
replace dy1 = 1 if yr1 < 1966
replace mt1 = 1 if yr1 < 1966
replace yr1 = 1966 if yr1 < 1966
replace mt1 = 1 if mt1 == 0
replace dy1 = 1 if dy1 == 0
replace dy1 = 28 if dy1 > 28 & mt1 == 2 & yr1 != 1972 & yr1 != 1976 & yr1 != 1980 & yr1 != 1984 & yr1 != 1988 & yr1 != 1992 & yr1 != 1996 & yr1 != 2000 & yr1 != 2004 & yr1 != 2008 & yr1 != 2012
gen exit = mdy(mt1,dy1,yr1)
drop exdate yr mt dy yr1 mt1 dy1

* Correct spells that ended before they started (typos, only a handful)
sort person_id entry exit firm_id_sec
gen ex_0 = exit
replace ex_0 = entry if entry > exit
* Eliminate spells that ended before an ongoing spell
* Short-duration spells (median duration is a week, 1 out of 5 seem to be one-day contracts)
gen ex_1 = ex_0
replace ex_1 = . if ex_0 <= ex_0[_n-1] & person_id == person_id[_n-1]
gen uno = 1
egen total = sum(uno), by (person_id)
egen max = max(total)
gen max_j = max - 1
local max_obs "max"
local max_obs_j "max_j"
local i = 2
local j = 1
while `i' < `max_obs' {
  while `j' < `max_obs_j' {
    gen ex_`i' = ex_`j'
    replace ex_`i' = . if ex_0 <= ex_0[_n-`i'] & person_id == person_id[_n-`i']
    drop ex_`j'
    local j = `j' + 1
    local i = `i' + 1
  }
}
drop ex_0
rename ex_* exit_1
compress
drop if exit_1 == .

* Adjust starting date for spells that started before a previous spell had ended
gen entry_1 = entry
replace entry_1 = . if entry_1 < exit_1[_n-1] & entry_1 ~= entry_1[_n-1] & person_id == person_id[_n-1]
gen entry_2 = entry_1
replace entry_2 = exit_1[_n-1] + 1 if entry_2 == . & exit_1[_n-1] >= entry & person_id == person_id[_n-1]
* Identify spells that have a same starting date (keep the longest spell)
bys person_id entry_2: gen count = _n
bys person_id entry_2: egen maxcount = max(count)
bys person_id entry_2: egen maxdate = max(exit_1)
drop if maxcount > 1 & maxdate ~= exit_1
drop entry - max_j entry_1 count - maxdate

* Verify  unique identification: at this point working lives do not register overlapping spells on a daily basis
bys person_id entry_2: gen count = _n
drop if count ~= 1
rename entry_2 entry_1
save "../../tmp/continuous_spells", replace

** Goal: transform data set to individual-spell-year level
* Merge with information on earnings at that same level
gen yrst = year(entry_1)
gen yren = year(exit_1)
forvalues x = 1980 / 2011 {
  gen year_`x' = `x'
  replace year_`x' = . if yrst > year_`x'
  replace year_`x' = . if yren < year_`x'
}
drop disability firm_ett firm_jur_type firm_jur_status firm_id_main count - yren
compress
* Generate unique identifier to reshape data 
reshape long year_, i(person_id firm_id_sec entry_1 exit_1) j(year)
drop if year_ == .
* At this stage, an individual can have continuous entries and exits within the same firm in a given year
* These multiple entires and exits do not necessarily correspond to firm changes
* Keep the first observation in the year when there is more than one observation per spell (person + firm)
bys person_id firm_id_sec year: gen count = _n
drop if count != 1
drop year_ count
* Merge with MCVL earnings information by individual-spell-year
merge 1:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_1", update
drop if _merge == 2 
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_2", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_3", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_4", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_5", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_6", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_7", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_8", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_9", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_10", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_11", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_12", update
drop if _merge == 2
drop _merge
merge m:m person_id firm_id_sec year using "../../tmp/mcvl_earnings_13", update
drop if _merge == 2
drop _merge

** Identify main activity in a given year and month
* First, identify years in which individuals had more than one spell 
* At this stage, individuals may have more than one spell by year and month if they worked in more than one firm (or spent some time unemployed)
sort person_id entry_1 exit_1 year
egen count = seq(), by (person_id year)
egen num = max(count), by (person_id year)
* Second, consider only characteristics for the spells with the highest income by year and month
local i = 1
while `i' < 13 {
  gsort person_id year -earnings_`i' entry_1 exit_1
  egen rank_`i' = seq() if num > 1 & earnings_`i' != ., by (person_id year)
  local i = `i' + 1
}
sort person_id entry_1 exit_1 year
local i = 1
while `i' < 13 {
  gen firm_id_se_`i' = firm_id_sec if rank_`i' == 1
  egen firm_id_sec_`i' = mode(firm_id_se_`i') if num > 1, by (person_id year)
  replace firm_id_sec_`i' = firm_id_sec if num == 1 & earnings_`i' > 0
  gen regim_`i' = regime if rank_`i' == 1
  egen regime_`i' = max(regim_`i') if num > 1, by (person_id year)
  replace regime_`i' = regime if num == 1 & earnings_`i' > 0
  gen occupatio_`i' = occupation if rank_`i' == 1
  egen occupation_`i' = max(occupatio_`i') if num > 1, by (person_id year)
  replace occupation_`i' = occupation if num == 1 & earnings_`i' > 0
  gen contract_typ_`i' = contract_type if rank_`i' == 1
  egen contract_type_`i' = max(contract_typ_`i') if num > 1, by (person_id year)
  replace contract_type_`i' = contract_type if num == 1 & earnings_`i' > 0
  gen ptcoe_`i' = ptcoef if rank_`i' == 1
  egen ptcoef_`i' = max(ptcoe_`i') if num > 1, by (person_id year)
  replace ptcoef_`i' = ptcoef if num == 1 & earnings_`i' > 0
  gen firm_mun_`i' = firm_muni if rank_`i' == 1
  egen firm_muni_`i' = max(firm_mun_`i') if num > 1, by (person_id year)
  replace firm_muni_`i' = firm_muni if num == 1 & earnings_`i' > 0
  gen secto_`i' = sector_cnae93 if rank_`i' == 1
  egen sector_`i' = max(secto_`i') if num > 1, by (person_id year)
  replace sector_`i' = sector_cnae93 if num == 1 & earnings_`i' > 0
  gen job_relationshi_`i' = job_relationship if rank_`i' == 1
  egen job_relationship_`i' = max(job_relationshi_`i') if num > 1, by (person_id year)
  replace job_relationship_`i' = job_relationship if num == 1 & earnings_`i' > 0
  gen firm_id_ta_`i' = firm_id_tax if rank_`i' == 1
  egen firm_id_tax_`i' = max(firm_id_ta_`i') if num > 1, by (person_id year)
  replace firm_id_tax_`i' = firm_id_tax if num == 1 & earnings_`i' > 0
  gen earn_`i' = earnings_`i' if rank_`i' == 1
  egen wage_`i' = max(earn_`i') if num > 1, by (person_id year)
  replace wage_`i' = earnings_`i' if num == 1 & earnings_`i' > 0  
  drop rank_`i' firm_id_se_`i' regim_`i' occupatio_`i' contract_typ_`i' ptcoe_`i' firm_mun_`i' secto_`i' job_relationshi_`i' firm_id_ta_`i' earn_`i'
  local i = `i' + 1
}
* Third, we keep information only for the main activity
drop if count != 1
drop earnings_1 - earnings_12 count num

** We include changes in occupation and contract types over time
* Correct for changes in occupations 
destring prev_occupation, replace
gen yr = substr(new_date_occupation,1,4)
gen mt = substr(new_date_occupation,5,2)
gen dy = substr(new_date_occupation,7,2)
destring yr, replace
destring mt, replace
destring dy, replace
foreach num of numlist 1/12 {
  replace occupation_`num' = prev_occupation if year < yr & yr != . & occupation != prev_occupation & occupation != .
  replace occupation_`num' = prev_occupation if year == yr & yr != . & occupation != prev_occupation & mt + 1 > `num'
}
drop yr mt dy
* Correct for first change in contract (occurs prior to the second change)
destring prev_contract1, replace
destring prev_contract2, replace
destring prev_ptcoef1, replace
destring prev_ptcoef2, replace
destring new_date_contract1, gen(new1)
destring new_date_contract2, gen(new2)
replace new_date_contract1 = "" if new2 <= new1 & new2 != .
replace prev_contract1 = . if new_date_contract1 == "" & prev_contract1 != .
replace prev_ptcoef1 = . if new_date_contract1 == "" & prev_ptcoef1 != .
gen yr = substr(new_date_contract1,1,4)
gen mt = substr(new_date_contract1,5,2)
gen dy = substr(new_date_contract1,7,2)
destring yr, replace
destring mt, replace
destring dy, replace
foreach num of numlist 1/12 {
  gen c`num'_2  = contract_type_`num'
  gen pt`num'_2 = ptcoef_`num'
  replace contract_type_`num' = prev_contract1 if year < yr & yr != . & contract_type_`num' != prev_contract1 & contract_type != . & prev_contract1 != .
  replace ptcoef_`num' = prev_ptcoef1 if year < yr & yr != . & ptcoef_`num' != prev_ptcoef1 & ptcoef != . & prev_ptcoef1 != .
  replace contract_type_`num' = prev_contract1 if year == yr & yr != . & contract_type_`num' != prev_contract1 & contract_type != . & prev_contract1 != . & mt+1 > `num'
  replace ptcoef_`num' = prev_ptcoef1 if year == yr & yr != . & ptcoef_`num' != prev_ptcoef1 & ptcoef != . & prev_ptcoef1 != . & mt+1 > `num'
  replace c`num'_2 = . if contract_type_`num' == c`num'_2
  replace pt`num'_2 = . if ptcoef_`num' == pt`num'_2
  replace c`num'_2 = 1 if c`num'_2 != .
  replace pt`num'_2 = 1 if pt`num'_2 != .
}
drop yr mt dy new1 new2
* Correct for second change in contract
gen yr = substr(new_date_contract2,1,4)
gen mt = substr(new_date_contract2,5,2)
gen dy = substr(new_date_contract2,7,2)
destring yr, replace
destring mt, replace
destring dy, replace
foreach num of numlist 1/12 {
  replace contract_type_`num' = prev_contract2 if year < yr & yr != . & contract_type_`num' != prev_contract2 & contract_type != . & prev_contract2 != . & c`num'_2 != 1
  replace ptcoef_`num' = prev_ptcoef2 if year < yr & yr != . & ptcoef_`num' != prev_ptcoef2 & ptcoef != . & prev_ptcoef2 != . & pt`num'_2 != 1
  replace contract_type_`num' = prev_contract2 if year == yr & yr != . & contract_type_`num' != prev_contract2 & contract_type != . & prev_contract2 != . & mt+1 > `num' & c`num'_2 != 1
  replace ptcoef_`num' = prev_ptcoef2 if year == yr & yr != . & ptcoef_`num' != prev_ptcoef2 & ptcoef != . & prev_ptcoef2 != . & mt+1 > `num' & pt`num'_2 != 1
}

** Reshape annual data set of main activities into a year-month data set
keep person_id year firm_id_sec_1 - wage_12
reshape long firm_id_sec_ regime_ occupation_ contract_type_ ptcoef_ firm_muni_ sector_ job_relationship_ firm_id_tax_ wage_, i(person_id year) j(month)
compress
rename *_ *
rename (firm_muni wage) (muni_id earnings_ss)
replace firm_id_sec = "" if earnings_ss <= 0
foreach var of varlist regime - firm_id_tax {
  replace `var' = . if earnings_ss <= 0
}
replace earnings_ss = . if earnings_ss <= 0
save "../../tmp/main_activity", replace

** Create a monthly data set starting at the entry year in social security or 1966
use "../../tmp/continuous_spells", clear
gen yearonly = year(entry_1)
egen entry_year = min(yearonly), by (person_id)
keep person_id entry_year
gen uno = 1
collapse (mean) uno, by (person_id entry_year)
foreach num of numlist 1966/2011 {
  gen y`num' = .
  replace y`num' = 1 if `num' >= entry_year
}
drop entry_year uno
reshape long y, i(person_id)
rename _j year
drop if y == .
foreach num of numlist 1/12 {
  gen month`num'=.
}
drop y
reshape long month, i(person_id year)
drop month
rename _j month
save "../../tmp/year_month", replace

** Assign dates to inactivity periods
use "../../tmp/continuous_spells", clear
* Generate a variable to count days absent
gen daysout = entry_1 - exit_1[_n-1] - 1 if person_id == person_id[_n-1]
replace daysout = 0 if daysout == -1 | daysout == .
* Generate a date format for Stata 
gen dtstart = exit_1[_n-1] + 1 if daysout > 0
gen dtend = entry_1 - 1 if daysout > 0
gen yrst = year(dtstart)
gen mtst = month(dtstart)
gen dyst = day(dtstart)
gen yren = year(dtend)
gen mten = month(dtend)
gen dyen = day(dtend)
keep person_id entry_1 exit_1 daysout - dyen
order person_id entry_1 exit_1 daysout - dyen
format entry_1 %dD/N/Y
format exit_1 %dD/N/Y

** Count the number of inactivity days in each year-month
keep person_id entry_1 - dyen
sort person_id entry_1 exit_1
drop if daysout == 0 | daysout == .
* First, correct for multiple periods of absence within one month
* Note: only consider periods "within a month" and add them up
gen samemonth = 1 if yrst == yren & mtst == mten & yrst ~= .
egen numdaysout1 = sum(daysout) if samemonth == 1, by(person_id yrst mtst)
replace numdaysout1 = . if numdaysout1 == daysout
foreach var of varlist entry_1 - daysout dyst dyen samemonth {
  replace `var' = . if numdaysout1 ~= .
}
egen count = seq() if numdaysout1 ~= ., by (person_id yrst mtst)
drop if count > 1 & count ~= .
* Second, identify one-event cases of absence "within" one month
gen numdaysout2 = daysout if samemonth ~= .
foreach var of varlist entry_1 - daysout dyst dyen {
  replace `var' = . if numdaysout2 ~= .
}
drop samemonth count
save "../../tmp/inactivity", replace
* Third, analyze month-overlapping cases
drop yren mten dyen
gen daysmonth = 30 if mtst == 4 | mtst == 6 | mtst == 9 | mtst == 11
replace daysmonth = 31 if mtst == 1 | mtst == 3 | mtst == 5 | mtst == 7 | mtst == 8 | mtst == 10 | mtst == 12
replace daysmonth = 28 if mtst == 2
replace daysmonth = 29 if daysmonth == 28 & (yrst== 1968 | yrst == 1972 | yrst == 1976 | yrst == 1980 | yrst == 1984 | yrst == 1988 | yrst == 1992 | yrst == 1996 | yrst == 2000 | yrst == 2004 | yrst == 2008 | yrst == 2012)
replace daysmonth = . if numdaysout1 ~= . | numdaysout2 ~= .
gen numdaysout3 = daysmonth - dyst + 1
egen numdaysout = rsum(numdaysout1 numdaysout2 numdaysout3)
gen uno = 1
egen count = sum(uno), by (person_id yrst mtst)
collapse (sum) numdaysout (mean) count (min) daysout, by (person_id yrst mtst)
rename numdaysout entryout
rename count entrycount
rename daysout entrydays
save "../../tmp/inactivity_entry", replace
* Fourth, continue with "exit side" ("entry side" is completed) 
use "../../tmp/inactivity", clear
drop yrst mtst dyst
gen numdaysout3 = dyen if numdaysout1 == . & numdaysout2 == .
egen numdaysout = rsum(numdaysout*)
gen uno = 1
egen count = sum(uno), by (person_id yren mten)
collapse (sum) numdaysout (mean) count (min) daysout, by (person_id yren mten)
rename numdaysout exitout
rename count exitcount
rename daysout exitdays
save "../../tmp/inactivity_exit", replace

** Merge monthly data set since entry in social security with detailed inactivity periods
use "../../tmp/year_month", clear
rename (year month) (yrst mtst)
merge m:m person_id yrst mtst using "../../tmp/inactivity_entry"
drop _merge
rename (yrst mtst) (yren mten)
merge m:m person_id yren mten using "../../tmp/inactivity_exit"
rename (yren mten) (year month)
drop _merge
* Create a variable specifying the number of days absent in one month
gen daysout = entryout if entryout == exitout & entrycount == 1 & exitcount == 1
replace daysout = entryout if entrycount == 1 & exitcount == .
replace daysout = exitout if entrycount == . & exitcount == 1
replace daysout = entryout + exitout if entrycount == 1 & exitcount == 1 & entrydays !=. & exitdays != . & daysout == .
replace daysout = entryout if entrycount == 2 & exitcount == 1 & entrydays !=. & daysout == .
replace daysout = exitout if entrycount == 1 & exitcount == 2 & exitdays !=. & daysout == .
replace daysout = entryout + 1 if entrycount == 2 & exitcount == 2 & entryout > exitout & daysout ==.
replace daysout = exitout + 1 if entrycount == 2 & exitcount == 2 & entryout <= exitout & daysout == .
* Correct for long periods of absence (those that comprise at least two months)
gen count = 1 if entrydays ~= .
replace count = 2 if count[_n-1] == 1 & person_id == person_id[_n-1] & exitdays == .
local i = 3
while `i' < 577 {
  replace count = `i' if count[_n-1] == `i' - 1 & exitdays == . & person_id == person_id[_n-`i']
  local i = `i' + 1
}
replace count = . if count == 1
* Generate a variable specifying the number of days worked in a month
gen daysmonth = 30 if month == 4 | month == 6 | month == 9 | month == 11
replace daysmonth = 31 if month == 1 | month == 3 | month == 5 | month == 7 | month == 8 | month == 10 | month == 12
replace daysmonth = 28 if month == 2
replace daysmonth = 29 if month == 2 & (year == 1968 | year == 1972 | year == 1976 | year == 1980 | year == 1984 | year == 1988 | year == 1992 | year == 1996 | year == 2000 | year == 2004 | year == 2008 | year == 2012)
gen monthwork = daysmonth - daysout
gen days_worked_month = 0 if count ~= .
replace days_worked_month = monthwork if monthwork ~= .
replace days_worked_month = daysmonth if days_worked_month == .
drop entryout - count monthwork
save "../../tmp/dayswork_only", replace

** Merge year-monthly data set of inactivity periods with data on main activity
merge 1:1 person_id year month using "../../tmp/main_activity"
drop _merge
* Replace with missings all recorded job characteristics for which the number of working days is zero
* These are less than 1% of the observations
replace firm_id_sec = "" if days_worked_month == 0 & firm_id_sec != ""
foreach var of varlist regime - earnings_ss {
  replace `var' = . if days_worked_month == 0 & `var' != .
}
* Replace with zeros all positive number of working days for which there is no information on job characteristics
replace days_worked_month = . if days_worked_month > 0 & (firm_id_sec == "" | occupation == .) & year >= 1980

** Generate worker time-varying variables
* Cumulative labour market experience
sort person_id year month
by person_id: gen experience = sum(days_worked_month) if (job_relationship < 749 | job_relationship > 760)
* Cumulative tenure within each firm/job
sort person_id firm_id_sec year month
by person_id firm_id_sec: gen tenure = sum(days_worked_month) if firm_id_sec != "" & (job_relationship < 749 | job_relationship > 760)
* Cumulative labour experience by urban area size category
* Experience in two biggest cities, 3rd to 5th biggest cities and smaller cities
* Note: 3rd to 5th biggest cities include experience accumulated in Bilbao (see data description in article for details) 
merge m:1 muni_id using "../../otherdata/ua_muni", keepusing(ua_id)
drop if _merge == 2
drop _merge
* Madrid and Barcelona
gen size = 1 if ua_id == 1 | ua_id == 2
* Valencia, Sevilla, (Bilbao) and Zaragoza
replace size = 2 if ua_id == 3 | ua_id == 4 | ua_id == 6 | ua_id == 8
* Smaller cities
replace size = 3 if size == . & ua_id != . 
sort person_id size year month
by person_id: gen uexp_1_2 = sum(days_worked_month) if size == 1 & (job_relationship < 749 | job_relationship > 760)
by person_id: gen uexp_3_5 = sum(days_worked_month) if size == 2 & (job_relationship < 749 | job_relationship > 760) 
by person_id: gen uexp_smaller = sum(days_worked_month) if size == 3 & (job_relationship < 749 | job_relationship > 760)
sort person_id year month
foreach var of varlist uexp_1_2 - uexp_smaller {
  replace `var' = 0 if `var' == .
  replace `var' = `var'[_n-1] if `var' == 0 & person_id == person_id[_n-1]
  replace `var' = . if ua_id == . | (job_relationship > 749 & job_relationship < 760)
}
* Cumulative labour experience in current urban area
sort person_id ua_id year month
by person_id ua_id: gen uexp_current = sum(days_worked_month) if ua_id != . & (job_relationship < 749 | job_relationship > 760)
* Time elapsed since last spell in two biggest cities
gen ua_1_2 = 1 if ua_id == 1 | ua_id == 2
gen date = (year - 1980) * 12 + month
gen big = 0
replace big = 1 if ua_1_2[_n-1] == 1 & ua_1_2 != 1 & person_id == person_id[_n-1]
gen left_ = date - date[_n-1] if big == 1
gen left_1_2 = daysmonth if left_ == 1
replace big = 1 if big[_n-1] == 1 & big == 0 & ua_1_2 != 1 & person_id == person_id[_n-1]
replace left_ = date - date[_n-1] if big == 1 & left_ == .
replace left_1_2 = left_1_2[_n-1] + left_ * daysmonth if left_1_2 == . & left_ != .
replace left_1_2 = 0 if left_1_2 == .
drop size ua_1_2 big left_
* Time elapsed since last spell in cities ranked 3-5th
* Again this set of cities includes Bilbao (see data description in article for details)
gen ua_3_5 = 1 if ua_id == 3 | ua_id == 4 | ua_id == 6 | ua_id == 8
gen big = 0
replace big = 1 if ua_3_5[_n-1] == 1 & ua_3_5 != 1 & person_id == person_id[_n-1]
gen left_ = date - date[_n-1] if big == 1
gen left_3_5 = daysmonth if left_ == 1
replace big = 1 if big[_n-1] == 1 & big == 0 & ua_3_5 != 1 & person_id == person_id[_n-1]
replace left_ = date - date[_n-1] if big == 1 & left_ == .
replace left_3_5 = left_3_5[_n-1] + left_ * daysmonth if left_3_5 == . & left_ != .
replace left_3_5 = 0 if left_3_5 == .
drop ua_3_5 big left_
* We generate time elapsed since last spell in cities ranked 1-6th
gen ua_1_5 = 1 if ua_id == 1 | ua_id == 2 | ua_id == 3 | ua_id == 4 | ua_id == 6 | ua_id == 8
gen big = 0
replace big = 1 if ua_1_5[_n-1] == 1 & ua_1_5 != 1 & person_id == person_id[_n-1]
gen left_ = date - date[_n-1] if big == 1
gen left_1_5 = daysmonth if left_ == 1
replace big = 1 if big[_n-1] == 1 & big == 0 & ua_1_5 != 1 & person_id == person_id[_n-1]
replace left_ = date - date[_n-1] if big == 1 & left_ == .
replace left_1_5 = left_1_5[_n-1] + left_ * daysmonth if left_1_5 == . & left_ != .
replace left_1_5 = 0 if left_1_5 == .
drop daysmonth date ua_1_5 big left_

** Add individual characteristics
merge m:1 person_id using "../../tmp/mcvl_cdf_2011/individuals", keepusing(birth_date - ss_reg_prov birth_country edu_code)
drop if _merge == 2
drop _merge
rename earnings_ss earnings_capped_ss
order person_id - month birth_date sex edu_code nationality birth_prov birth_country ss_reg_prov days_worked_month experience tenure ua_id uexp* left_* earnings* 
compress
* Label variables
label var year "Year"
label var month "Month"
label var days_worked_month "Days worked in month"
label var experience "Days of work experience"
label var tenure "Days of tenure in the firm"
label var uexp_1_2 "Days of work experience in two biggest cities"
label var uexp_3_5 "Days of work experience in 3rd-5th biggest cities"
label var uexp_smaller "Days of work experience outside 5 biggest cities"
label var uexp_current "Days of work experience in current city"
label var left_1_2 "Days elapsed since last spell in two biggest cities"
label var left_3_5 "Days elapsed since last spell in 3rd-5th biggest cities"
label var left_1_5 "Days elapsed since last spell in 1st-5th biggest cities"
label var earnings_capped_ss "Monthly nominal wage recorded for SS contributions (possibly capped) in cents"
label var firm_id_sec "Firm establishment identifier"
label var regime "Social security regime"
label var occupation "Occupational code"
label var contract_type "Type of job contract"
label var ptcoef "Part time coefficient in 1/1000 of full-time equivalent, 0 if full-time"
label var muni_id "Firm municipality if population above 40000"
label var sector "3-digit sector code"
label var job_relationship "Type of job relationship"
label var firm_id_tax "Firm establishment identifier for matching with tax data"

* Erase temporary data sets
erase "../../tmp/raw_cohort.dta"
erase "../../tmp/continuous_spells.dta"
erase "../../tmp/main_activity.dta"
erase "../../tmp/year_month.dta"
erase "../../tmp/inactivity.dta"
erase "../../tmp/inactivity_entry.dta"
erase "../../tmp/inactivity_exit.dta"
erase "../../tmp/dayswork_only.dta"
