/*-----------------------------------------------------------------------
mcvl_firm_cnae93.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Creates panel of firms with (time-varying) economic sector CNAE93
-----------------------------------------------------------------------*/

** Create annual panel of firms with sector of economic activity 
* Firm establishment sector of economic activity corresponds to the year when MCVL information is retrieved (e.g. 2013 MCVL wave)
* It does not change over time within a MCVL wave, however, it can be identified when different MCVL waves are combined
* Between 2004 and 2008 only CNAE93 is provided; in MCVL 2009 only CNAE09 is provided (no information on CNAE93)
* Since MCVL 2010, both sector classifications are recorded but CNAE93 reflects the value in 2009
* CNAE93 is consistently available between 2004 and 2008, but values after 2009 need to be updated if a establishment changes sector of activity
* Likewise, if an establsihment is created after 2008, only CNAE09 is available

* Identify firm establishment in each MCVL wave
forvalues x = 2004(1)2012 {
  use "../../tmp/mcvl_cdf_`x'/affiliates_1", clear
  append using "../../tmp/mcvl_cdf_`x'/affiliates_2"
  append using "../../tmp/mcvl_cdf_`x'/affiliates_3"
  keep if regime == 111
  gen year = `x'
  egen count = seq(), by (firm_id_sec)
  keep if count == 1
  keep firm_id_sec year sector*
  save "../../tmp/sector_`x'", replace
}

use "../../tmp/mcvl_cdf_2013/affiliates_1", clear
append using "../../tmp/mcvl_cdf_2013/affiliates_2"
append using "../../tmp/mcvl_cdf_2013/affiliates_3"
append using "../../tmp/mcvl_cdf_2013/affiliates_4"
keep if regime == 111
gen year = 2013
egen count = seq(), by (firm_id_sec)
keep if count == 1
keep firm_id_sec year sector*
save "../../tmp/sector_2013", replace

* Combine all waves
use "../../tmp/sector_2004", clear
forvalues x= 2005(1)2013 {
  append using "../../tmp/sector_`x'"
}
sort firm_id_sec year
save "../../tmp/sector_all", replace

* Generate a crosswalk between CNAE09 and CNAE03
keep sector sector_cnae93
keep if sector_cnae93 != . & sector_cnae93 != 0 & sector != . & sector != 0
sort sector sector_cnae93
egen count = seq(), by (sector sector_cnae93)
egen obs = max(count), by (sector sector_cnae93)
keep if count == 1
drop count
egen max = max(obs), by (sector)
drop if max != obs
keep sector*
rename sector sector_cnae09
order sector_cnae09 sector_cnae93
label var sector_cnae09 "3-digit sector CNAE 09"
label var sector_cnae93 "3-digit sector CNAE 93"
label data "'Learning by working in big cities' De la Roca & Puga. Crosswalk CNAE09-CNAE93"
save "../../tmp/xwalk_cnae09_cnae93", replace

** Update the economic sector CNAE93 of the establihsment
use "../../tmp/sector_all", clear
* Replace sector with CNAE93 in each year prior to 2009
gen sector_year = sector_cnae93 if year <= 2008
* Replace sector with zeros for establishment that exit in 2009 and after
replace sector_year = 0 if year >= 2009 & sector == 0 & sector_year == .
* Replace sector with CNAE93 for establishments that remain active in 2010 and after
replace sector_year = sector_cnae93 if year >= 2010 & sector != 0 & sector_cnae93 != 0 & sector_year == .
* Replace sector in 2009 with 2010 sector when sector in 2010 is available
replace sector_year = sector_year[_n+1] if year == 2009 & year[_n+1] == 2010 & sector_year[_n+1] != . & firm_id_sec == firm_id_sec[_n+1] & sector_year == .
* Replace sector in 2009 with the most recent sector available prior to 2009 (when sector is not available in 2010)
egen first_year = min(year), by (firm_id_sec)
replace sector_year = sector_year[_n-1] if year == 2009 & sector_year[_n-1] != . & firm_id_sec == firm_id_sec[_n-1] & first_year < 2009 & sector_year == .
* For establishments created in 2009 and after, impute economic actvity using crosswalk CNAE09 to CNAE93
* A few of remaining cases are establishments that did not operate in 2009, but operated after (no CNAE 93 was recorded after 2009) 
rename sector sector_cnae09
rename sector_cnae93 sector_93
merge m:1 sector_cnae09 using "../../tmp/xwalk_cnae09_cnae93"
sort firm_id_sec year
replace sector_year = sector_cnae93 if sector_cnae93 != . & sector_year == . 
drop sector_93 sector_cnae09 first_year sector_cnae93 _merge

* Labeling
label var firm_id_sec "Firm establishment identifier"
label var year "Year"
label var sector_year "3-digit sector (CNAE 93 updated from 2009 to 2013)"
save "../../tmp/firm_cnae93", replace

* Erase temporary data sets
forvalues x  = 2004(1)2013 {
  erase "../../tmp/sector_`x'.dta"
}
erase "../../tmp/sector_all.dta"
erase "../../tmp/xwalk_cnae09_cnae93.dta"
